![project icon](project-icon.svg)
# Socket Wrapper for Byte Strings
[![forthebadge](https://forthebadge.com/images/badges/contains-technical-debt.svg)](https://forthebadge.com) [![forthebadge](https://forthebadge.com/images/badges/made-with-python.svg)](https://forthebadge.com)


"A straight-forward wrapper for sending and receiving byte strings with sockets."

(Probably) thread safe, allowing for juggling of multiple clients with one server socket instance through threading.

## Documentation
To see documentation regarding installation and usage, please visit [the manual for this project](https://dreamerslegacy.xyz/projects/swbs/docs/index.html).

## Releases & Dist.
With the released wheel file, after downloading:
```commandline
pip3 install /path/to/wheel/file/here/swbs-1.2.4-py3-none-any.whl
```
...Or available on PyPI through:
```commandline
pip3 install swbs
```
Please see documentation for more information.

## For Versions < 1.2
Versions below 1.2 are deprecated and no longer supported. The documentation is no longer available, unless produced from a previous VCS commit.
